@@ -44,7 +44,7 @@
 */
 
 #ifndef gmic_version
-#define gmic_version 213
+#define gmic_version 215
 
 #include <cstdio>
 #include <cstring>
@@ -260,8 +260,10 @@ struct gmic {
                            const char operation='=',
                            const unsigned int *const variables_sizes=0);
 
-  gmic& add_commands(const char *const data_commands, const char *const commands_file=0);
-  gmic& add_commands(std::FILE *const file, const char *const filename=0);
+  gmic& add_commands(const char *const data_commands, const char *const commands_file=0,
+                     unsigned int *count_new=0, unsigned int *count_replaced=0);
+  gmic& add_commands(std::FILE *const file, const char *const filename=0,
+                     unsigned int *count_new=0, unsigned int *count_replaced=0);
 
   gmic_image<char> callstack2string(const bool is_debug=false) const;
   gmic_image<char> callstack2string(const gmic_image<unsigned int>& callstack_selection,
@@ -361,6 +363,7 @@ struct gmic {
 
   // Class variables.
   static const char *native_commands_names[];
+  static gmic_image<int> native_commands_inds;
   static gmic_image<char> stdlib;
 
   gmic_list<char> *const commands, *const commands_names, *const commands_has_arguments,
